@@ -1,4 +1,4 @@
-from typing import cast
+from typing import TYPE_CHECKING, cast
 
 from graphene import ResolveInfo
 
@@ -12,18 +12,28 @@ from ..external import get_external_pipeline_or_raise
 from ..utils import ExecutionMetadata, ExecutionParams, capture_error
 from .run_lifecycle import create_valid_pipeline_run
 
+if TYPE_CHECKING:
+    from dagster_graphql.schema.runs import GrapheneLaunchRunSuccess
+    from dagster_graphql.schema.util import HasContext
+
 
 @capture_error
-def launch_pipeline_reexecution(graphene_info, execution_params):
+def launch_pipeline_reexecution(
+    graphene_info: "HasContext", execution_params: ExecutionParams
+) -> "GrapheneLaunchRunSuccess":
     return _launch_pipeline_execution(graphene_info, execution_params, is_reexecuted=True)
 
 
 @capture_error
-def launch_pipeline_execution(graphene_info, execution_params):
+def launch_pipeline_execution(
+    graphene_info: "HasContext", execution_params: ExecutionParams
+) -> "GrapheneLaunchRunSuccess":
     return _launch_pipeline_execution(graphene_info, execution_params)
 
 
-def do_launch(graphene_info, execution_params, is_reexecuted=False):
+def do_launch(
+    graphene_info: "HasContext", execution_params: ExecutionParams, is_reexecuted: bool = False
+) -> DagsterRun:
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(execution_params, "execution_params", ExecutionParams)
     check.bool_param(is_reexecuted, "is_reexecuted")
@@ -44,7 +54,9 @@ def do_launch(graphene_info, execution_params, is_reexecuted=False):
     )
 
 
-def _launch_pipeline_execution(graphene_info, execution_params, is_reexecuted=False):
+def _launch_pipeline_execution(
+    graphene_info, execution_params: ExecutionParams, is_reexecuted: bool = False
+) -> "GrapheneLaunchRunSuccess":
     from ...schema.pipelines.pipeline import GrapheneRun
     from ...schema.runs import GrapheneLaunchRunSuccess
 
@@ -59,7 +71,9 @@ def _launch_pipeline_execution(graphene_info, execution_params, is_reexecuted=Fa
 
 
 @capture_error
-def launch_reexecution_from_parent_run(graphene_info, parent_run_id: str, strategy):
+def launch_reexecution_from_parent_run(
+    graphene_info: "HasContext", parent_run_id: str, strategy: str
+) -> "GrapheneLaunchRunSuccess":
     """
     Launch a re-execution by referencing the parent run id
     """
