@@ -1,13 +1,21 @@
+from itertools import chain
+from typing import TYPE_CHECKING
+
 import dagster._check as check
+from dagster._core.definitions.instigation_logger import get_instigation_log_records
 from dagster._core.definitions.run_request import InstigatorType
 from dagster._core.host_representation import InstigatorSelector
+from dagster._core.log_manager import DAGSTER_META_KEY
 from dagster._core.scheduler.instigation import InstigatorStatus
 
 from .utils import capture_error
 
+if TYPE_CHECKING:
+    from dagster_graphql.schema.util import HasContext
+
 
 @capture_error
-def get_unloadable_instigator_states_or_error(graphene_info, instigator_type=None):
+def get_unloadable_instigator_states_or_error(graphene_info: "HasContext", instigator_type=None):
     from ..schema.instigation import GrapheneInstigationState, GrapheneInstigationStates
 
     check.opt_inst_param(instigator_type, "instigator_type", InstigatorType)
@@ -18,10 +26,15 @@ def get_unloadable_instigator_states_or_error(graphene_info, instigator_type=Non
         instigator
         for repository_location in graphene_info.context.repository_locations
         for repository in repository_location.get_repositories().values()
-        for instigator in repository.get_external_schedules() + repository.get_external_sensors()
+        for instigator in chain(
+            repository.get_external_schedules(), repository.get_external_sensors()
+        )
     ]
 
-    instigator_selector_ids = {instigator.selector_id for instigator in external_instigators}
+    instigator_selector_ids = {
+        instigator.selector_id  # type: ignore # mypy getting confused by chain
+        for instigator in external_instigators
+    }
     unloadable_states = [
         instigator_state
         for instigator_state in instigator_states
@@ -63,3 +76,25 @@ def get_instigator_state_or_error(graphene_info, selector):
         return GrapheneInstigationStateNotFoundError(selector.name)
 
     return GrapheneInstigationState(current_state)
+
+
+def get_tick_log_events(graphene_info, tick):
+    from ..schema.instigation import GrapheneInstigationEvent, GrapheneInstigationEventConnection
+    from ..schema.logs.log_level import GrapheneLogLevel
+
+    if not tick.log_key:
+        return GrapheneInstigationEventConnection(events=[], cursor="", hasMore=False)
+
+    records = get_instigation_log_records(graphene_info.context.instance, tick.log_key)
+    return GrapheneInstigationEventConnection(
+        events=[
+            GrapheneInstigationEvent(
+                message=record_dict[DAGSTER_META_KEY]["orig_message"],
+                level=GrapheneLogLevel.from_level(record_dict["levelno"]),
+                timestamp=int(record_dict["created"] * 1000),
+            )
+            for record_dict in records
+        ],
+        cursor=None,
+        hasMore=False,
+    )
