@@ -1,9 +1,9 @@
 from graphene import ResolveInfo
 
 import dagster._check as check
-from dagster._core.storage.pipeline_run import PipelineRun
+from dagster._core.storage.pipeline_run import DagsterRun
 
-from .external import get_external_pipeline_or_raise, get_full_external_job_or_raise
+from .external import get_external_pipeline_or_raise, get_full_external_pipeline_or_raise
 from .utils import PipelineSelector, UserFacingGraphQLError, capture_error
 
 
@@ -13,7 +13,7 @@ def get_pipeline_snapshot_or_error_from_pipeline_selector(graphene_info, pipelin
 
     check.inst_param(pipeline_selector, "pipeline_selector", PipelineSelector)
     return GraphenePipelineSnapshot(
-        get_full_external_job_or_raise(graphene_info, pipeline_selector)
+        get_full_external_pipeline_or_raise(graphene_info, pipeline_selector)
     )
 
 
@@ -58,7 +58,7 @@ def get_pipeline_reference_or_raise(graphene_info, pipeline_run):
     InvalidSubsetError."""
     from ..schema.pipelines.pipeline_ref import GrapheneUnknownPipeline
 
-    check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+    check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
     solid_selection = (
         list(pipeline_run.solids_to_execute) if pipeline_run.solids_to_execute else None
     )
