@@ -20,7 +20,7 @@ from dagster_graphql.schema.solids import (
 
 from dagster import AssetKey
 from dagster import _check as check
-from dagster._core.definitions.asset_graph import AssetGraph
+from dagster._core.definitions.external_asset_graph import ExternalAssetGraph
 from dagster._core.definitions.logical_version import (
     DEFAULT_LOGICAL_VERSION,
     extract_logical_version_from_entry,
@@ -41,7 +41,6 @@ from ..implementation.fetch_assets import (
     get_materialization_cts_by_partition,
     get_materialization_cts_grouped_by_dimension,
 )
-from ..implementation.fetch_runs import AssetComputeStatus
 from ..implementation.loader import (
     BatchMaterializationLoader,
     CrossRepoAssetDependedByLoader,
@@ -114,7 +113,6 @@ class GrapheneAssetDependency(graphene.ObjectType):
 class GrapheneAssetLatestInfo(graphene.ObjectType):
     assetKey = graphene.NonNull(GrapheneAssetKey)
     latestMaterialization = graphene.Field(GrapheneMaterializationEvent)
-    computeStatus = graphene.NonNull(graphene.Enum.from_enum(AssetComputeStatus))
     unstartedRunIds = non_null_list(graphene.String)
     inProgressRunIds = non_null_list(graphene.String)
     latestRun = graphene.Field(GrapheneRun)
@@ -169,6 +167,7 @@ class GrapheneAssetNode(graphene.ObjectType):
     groupName = graphene.String()
     id = graphene.NonNull(graphene.ID)
     isObservable = graphene.NonNull(graphene.Boolean)
+    isPartitioned = graphene.NonNull(graphene.Boolean)
     isSource = graphene.NonNull(graphene.Boolean)
     jobNames = non_null_list(graphene.String)
     jobs = non_null_list(GraphenePipeline)
@@ -236,7 +235,7 @@ class GrapheneAssetNode(graphene.ObjectType):
             assetKey=external_asset_node.asset_key,
             description=external_asset_node.op_description,
             opName=external_asset_node.op_name,
-            opVersion=external_asset_node.op_version,
+            opVersion=external_asset_node.code_version,
             groupName=external_asset_node.group_name,
         )
 
@@ -381,12 +380,14 @@ class GrapheneAssetNode(graphene.ObjectType):
         except ValueError:
             before_timestamp = None
         limit = kwargs.get("limit")
+        partitions = kwargs.get("partitions")
+
         return [
             GrapheneObservationEvent(event=event)
             for event in get_asset_observations(
                 graphene_info,
                 self._external_asset_node.asset_key,
-                # partitions,
+                partitions,
                 before_timestamp=before_timestamp,
                 limit=limit,
             )
@@ -423,7 +424,10 @@ class GrapheneAssetNode(graphene.ObjectType):
             return (logical_version or DEFAULT_LOGICAL_VERSION).value
 
     def resolve_projectedLogicalVersion(self, _graphene_info) -> Optional[str]:
-        if self.external_asset_node.is_source:
+        if (
+            self.external_asset_node.is_source
+            or self.external_asset_node.partitions_def_data is not None
+        ):
             return None
         else:
             loader = check.not_none(
@@ -515,9 +519,7 @@ class GrapheneAssetNode(graphene.ObjectType):
 
     def resolve_freshnessInfo(self, graphene_info) -> Optional[GrapheneAssetFreshnessInfo]:
         if self._external_asset_node.freshness_policy:
-            asset_graph = AssetGraph.from_external_assets(
-                self._external_repository.get_external_asset_nodes()
-            )
+            asset_graph = ExternalAssetGraph.from_external_repository(self._external_repository)
             return get_freshness_info(
                 asset_key=self._external_asset_node.asset_key,
                 freshness_policy=self._external_asset_node.freshness_policy,
@@ -547,6 +549,9 @@ class GrapheneAssetNode(graphene.ObjectType):
     def resolve_isSource(self, _graphene_info) -> bool:
         return self.is_source_asset()
 
+    def resolve_isPartitioned(self, _graphene_info) -> bool:
+        return self._external_asset_node.partitions_def_data is not None
+
     def resolve_isObservable(self, _graphene_info) -> bool:
         return self._external_asset_node.is_observable
 
