@@ -15,7 +15,15 @@ from dagster._core.host_representation import (
     ManagedGrpcPythonEnvRepositoryLocationOrigin,
     RepositoryLocation,
 )
-from dagster._core.workspace.context import WorkspaceLocationEntry, WorkspaceLocationLoadStatus
+from dagster._core.host_representation.grpc_server_state_subscriber import (
+    LocationStateChangeEvent,
+    LocationStateSubscriber,
+)
+from dagster._core.workspace.context import (
+    WorkspaceLocationEntry,
+    WorkspaceLocationLoadStatus,
+    WorkspaceProcessContext,
+)
 
 from .asset_graph import GrapheneAssetGroup, GrapheneAssetNode
 from .errors import GraphenePythonError, GrapheneRepositoryNotFoundError
@@ -25,7 +33,7 @@ from .repository_origin import GrapheneRepositoryMetadata, GrapheneRepositoryOri
 from .schedules import GrapheneSchedule
 from .sensors import GrapheneSensor
 from .used_solid import GrapheneUsedSolid
-from .util import non_null_list
+from .util import HasContext, non_null_list
 
 
 class GrapheneLocationStateChangeEventType(graphene.Enum):
@@ -107,6 +115,38 @@ class GrapheneRepositoryLocationOrLoadError(graphene.Union):
         name = "RepositoryLocationOrLoadError"
 
 
+class GrapheneWorkspaceLocationStatusEntry(graphene.ObjectType):
+    id = graphene.NonNull(graphene.ID)
+    name = graphene.NonNull(graphene.String)
+    loadStatus = graphene.NonNull(GrapheneRepositoryLocationLoadStatus)
+    updateTimestamp = graphene.NonNull(graphene.Float)
+
+    class Meta:
+        name = "WorkspaceLocationStatusEntry"
+
+    def __init__(self, name, load_status, update_timestamp):
+        super().__init__(name=name, loadStatus=load_status, updateTimestamp=update_timestamp)
+
+    def resolve_id(self, _):
+        return f"location_status:{self.name}"
+
+
+class GrapheneWorkspaceLocationStatusEntries(graphene.ObjectType):
+    entries = non_null_list(GrapheneWorkspaceLocationStatusEntry)
+
+    class Meta:
+        name = "WorkspaceLocationStatusEntries"
+
+
+class GrapheneWorkspaceLocationStatusEntriesOrError(graphene.Union):
+    class Meta:
+        types = (
+            GrapheneWorkspaceLocationStatusEntries,
+            GraphenePythonError,
+        )
+        name = "WorkspaceLocationStatusEntriesOrError"
+
+
 class GrapheneWorkspaceLocationEntry(graphene.ObjectType):
     id = graphene.NonNull(graphene.ID)
     name = graphene.NonNull(graphene.String)
@@ -118,7 +158,7 @@ class GrapheneWorkspaceLocationEntry(graphene.ObjectType):
     class Meta:
         name = "WorkspaceLocationEntry"
 
-    def __init__(self, location_entry):
+    def __init__(self, location_entry: WorkspaceLocationEntry):
         self._location_entry = check.inst_param(
             location_entry, "location_entry", WorkspaceLocationEntry
         )
@@ -170,7 +210,12 @@ class GrapheneRepository(graphene.ObjectType):
     class Meta:
         name = "Repository"
 
-    def __init__(self, instance, repository, repository_location):
+    def __init__(
+        self,
+        instance: DagsterInstance,
+        repository: ExternalRepository,
+        repository_location: RepositoryLocation,
+    ):
         self._repository = check.inst_param(repository, "repository", ExternalRepository)
         self._repository_location = check.inst_param(
             repository_location, "repository_location", RepositoryLocation
@@ -315,19 +360,22 @@ class GrapheneLocationStateChangeSubscription(graphene.ObjectType):
         name = "LocationStateChangeSubscription"
 
 
-async def gen_location_state_changes(graphene_info):
+async def gen_location_state_changes(graphene_info: HasContext):
 
     # This lives on the process context and is never modified/destroyed, so we can
     # access it directly
     context = graphene_info.context.process_context
 
-    queue = asyncio.Queue()
+    if not isinstance(context, WorkspaceProcessContext):
+        return
+
+    queue: asyncio.Queue[LocationStateChangeEvent] = asyncio.Queue()
     loop = asyncio.get_event_loop()
 
-    def _enqueue(event, cursor):
-        loop.call_soon_threadsafe(queue.put_nowait, (event, cursor))
+    def _enqueue(event):
+        loop.call_soon_threadsafe(queue.put_nowait, event)
 
-    token = context.add_state_subscriber(_enqueue)
+    token = context.add_state_subscriber(LocationStateSubscriber(_enqueue))
     try:
         while True:
             event = await queue.get()
