@@ -3,8 +3,9 @@ import sys
 import graphene
 
 import dagster._check as check
-from dagster._core.instance import DagsterInstance, is_dagit_telemetry_enabled
+from dagster._core.instance import DagsterInstance
 from dagster._core.launcher.base import RunLauncher
+from dagster._core.storage.captured_log_manager import CapturedLogManager
 from dagster._daemon.types import DaemonStatus
 
 from .errors import GraphenePythonError
@@ -94,7 +95,7 @@ class GrapheneInstance(graphene.ObjectType):
     executablePath = graphene.NonNull(graphene.String)
     daemonHealth = graphene.NonNull(GrapheneDaemonHealth)
     hasInfo = graphene.NonNull(graphene.Boolean)
-    dagitTelemetryEnabled = graphene.NonNull(graphene.Boolean)
+    hasCapturedLogManager = graphene.NonNull(graphene.Boolean)
 
     class Meta:
         name = "Instance"
@@ -127,5 +128,5 @@ class GrapheneInstance(graphene.ObjectType):
     def resolve_daemonHealth(self, _graphene_info):
         return GrapheneDaemonHealth(instance=self._instance)
 
-    def resolve_dagitTelemetryEnabled(self, _graphene_info):
-        return is_dagit_telemetry_enabled(self._instance)
+    def resolve_hasCapturedLogManager(self, _graphene_info):
+        return isinstance(self._instance.compute_log_manager, CapturedLogManager)
